Buffer abstraction for I/O operations.
Structs
Traits
- IoBuf
- A poll-based I/O and completion-based I/O buffer compatible buffer.
The
IoBuftrait is implemented by buffer types that can be used withcrate::Read. Fusio has already implemented this trait for common buffer types likeVec<u8>,&[u8],&mut [u8],bytes::Bytes,bytes::BytesMut, every buffer type may be not be able to be used in all async runtimes, fusio provides compile-time safety to ensure which buffer types are compatible with the async runtime. - IoBuf
Mut - Mutable version of
IoBufwhich is used withcrate::Write. - Maybe
Owned